/********************************
 *  Ford-Fulkerson algorithm    *
 *  for computing max flow      *                                              *
 *  s - the source vertex       *
 *  t - the sink vertex         *
 *  Edmonds-Karp implementation *
 ********************************
*/

#include <iostream>
#include <vector>
#include <queue>
#include <cstring>

using namespace std;

const int INF =1000000;
const int NMAX = 100;
const int MMAX = 10000;


struct edge
{ int u,v;
  int f,c,d;
};


int n,m;
edge e[MMAX];

vector<int> a[NMAX], b[NMAX];
int s, t;
int flow;

bool vis[NMAX];
int pred[NMAX];
int last[NMAX];

bool bfs(int s)
{ memset(vis,0,sizeof(bool)*(n+1));
  memset(pred,0,sizeof(int)*(n+1));
  memset(last,0,sizeof(int)*(n+1));

  queue<int> q;
  q.push(s);
  vis[s] = true;
  pred[s] = 0;
  last[s] = 0;

  while(!q.empty() and !vis[t])
  { int u = q.front(); q.pop();

    for(int i: a[u])
    { int v = e[i].v;
      if(!vis[v] and e[i].f<e[i].c)
      { q.push(v);
        vis[v]=true;
        pred[v] = u;
        last[v] = i;
        e[i].d = e[i].c-e[i].f;
      }
    }

    int v = u;
    for(int i: b[v])
    { int u = e[i].u;
      if(!vis[u] and e[i].f>0)
      { q.push(u);
        vis[u]=true;
        pred[u] = v;
        last[u] = i;
        e[i].d = e[i].f;
      }
    }
  }

  return vis[t];
}

void update_flow()
{ int dmin = INF;
  int v = t;
  while(v!=s)
  { int i = last[v];
    if(dmin>e[i].d) dmin=e[i].d;
    v = pred[v];
  }

  v = t;
  while(v!=s)
  { int i = last[v];
    if(e[i].v==v)
      e[i].f += dmin;
    else
      e[i].f -= dmin;
    v = pred[v];
  }

  flow = flow + dmin;
}

int main()
{ cin >> n;
  cin >> m;
  for(int i=0; i<m; i++)
  { int u,v,c;
    cin >> u >> v >> c;
    e[i].u = u; e[i].v = v; e[i].c = c;
    e[i].f = 0; e[i].d = 0;
    a[u].push_back(i);
    b[v].push_back(i);
  }

  s = 1; t = n;
  flow = 0;
  while(bfs(s))
  { update_flow();
    cout << flow << endl;
  }

  cout << flow << endl;
  return 0;
}
